@@ -1,9 +1,8 @@
 package Enbld::Definition;
 
-use 5.012;
+use strict;
 use warnings;
 
-use Module::Load;
 use Module::Load::Conditional qw/can_load/;
 
 require Enbld::Error;
@@ -14,7 +13,11 @@ sub new {
 
     my $self = {
         defined => {
+            DefaultArgument     =>  undef,
+            DarwinArgument      =>  undef,
+
             AdditionalArgument  =>  undef,
+
             AllowedCondition    =>  undef,
             ArchiveName         =>  undef,
             CopyFiles           =>  undef,
@@ -34,7 +37,9 @@ sub new {
 #           VersionCondition    =>  undef,
             VersionForm         =>  undef,
             WebSite             =>  undef,
-            
+           
+            TestAction          =>  undef,
+
             CommandConfigure    =>  undef,
             CommandMake         =>  undef,
             CommandTest         =>  undef,
@@ -44,15 +49,14 @@ sub new {
 
     my $module = 'Enbld::Definition::' . ucfirst( $name );
 
-    if ( can_load( modules => { $module => undef } ) ) {
-        bless $self, $module;
+    can_load( modules => { $module => 0 } ) or
+        die( Enbld::Error->new( "no definition for target '$name'" ));
 
-        $self->initialize;
+    bless $self, $module;
 
-        return $self;
-    }
+    $self->initialize;
 
-    die( Enbld::Error->new( "no definition for target '$name'" ));
+    return $self;
 }
 
 sub initialize {
